
package cs4411pa3;

import java.io.File;
import java.io.FileReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.math.BigInteger;

/**
 *  A BigIntegerReader provides a read() method to read a sequence of
 *  big integers from a file.
 *  Each big integer in the file should be in hexadecimal.
 *  The string of hexadecimal digits for a big integer may be chopped
 *  into lines.
 *  Each big integer should be followed by a blank line.
 */
public class BigIntegerReader {

    private BufferedReader reader;
    private StringBuffer buffer;

    /**
     *  new BigIntegerReader(fnm) returns a BigIntegerReader that reads
     *  big integers from the file named fnm.
     */
    public BigIntegerReader(String fnm)
    throws FileNotFoundException {
        this(new File(fnm));
    }  // public BigIntegerReader(String)

    /**
     *  new BigIntegerReader(f) returns a BigIntegerReader that reads
     *  big integers from the file f.
     */
    public BigIntegerReader(File f)
    throws FileNotFoundException {
        this(new FileReader(f));
    }  // public BigIntegerReader(File)

    /**
     *  new BigIntegerReader(strm) returns a BigIntegerReader that reads
     *  big integers from the input stream strm.
     */
    public BigIntegerReader(InputStream strm) {
        this(new InputStreamReader(strm));
    }  // public BigIntegerReader(InputStream)

    /**
     *  new BigIntegerReader(rdr) returns a BigIntegerReader that reads
     *  big integers from the reader rdr.
     */
    public BigIntegerReader(Reader rdr) {
        this(new BufferedReader(rdr));
    }  // public BigIntegerReader(Reader)

    /**
     *  new BigIntegerReader(rdr) returns a BigIntegerReader that reads
     *  big integers from the buffered reader rdr.
     */
    public BigIntegerReader(BufferedReader rdr) {
        reader = rdr;
        buffer = new StringBuffer();
    }  // public BigIntegerReader(BufferedReader)

    /**
     *  bir.read() returns the next big integer from the file or stream
     *  that bir is reading.
     */
    public BigInteger read()
    throws IOException {
        // Clear buffer.
        buffer.setLength(0);
        // FIXME - if the first line read is null then return null.
        // Otherwise, read lines and append them to buffer until a
        // line with 0 length is read.
        return new BigInteger(buffer.toString(), 16);
    }  // public BigInteger read()

    /**
     *  bir.close() closes the file  or stream that bir is reading.
     */
    public void close()
    throws IOException {
        reader.close();
    }  // public void close()

}  // public class BigIntegerReader

